
 library IEEE;  

 use IEEE.NUMERIC_STD.all;  
 Use IEEE.std_logic_1164.all;   
 Use IEEE.std_logic_arith.all; 
 use IEEE.std_logic_unsigned.all;  

  entity SCX6K1 is port(

 -- CPU Module interface
	RST_ALL_N		:in std_logic;-- Reset source from CPU board
	PB_PULL_N		:in std_logic; --push button
	RIO				:inout std_logic_vector ( 3 downto 0);
	FAN_SPD_CTRL_IN	:in std_logic;
	RST_CPLD_N		:in std_logic;

	RPS_INT_ON		:out std_logic;
	CPLD_INT_ON		:out std_logic;
	SFP_INT_ON		:out std_logic;
	TS_INT_ON		:out std_logic;
	
	HW_REV		:in std_logic_vector( 3 downto 0);

	SLOW_CLK	:in  std_logic;         
	SLOW_CLK2	:in  std_logic;         
	SDA_BRD		:inout std_logic;  	--  I2C data
	SCLK_BRD	:in  std_logic;          --  I2C clock
	
 --	RPS interface
	RPS1_DCOK_N		:in std_logic;
	RPS2_DCOK_N		:in std_logic;
	RPS1_PRSNT_N	:in std_logic;
	RPS2_PRSNT_N	:in std_logic;
	RPS1_FAIL_N		:in std_logic;
	RPS2_FAIL_N		:in std_logic;
	
--Fan Module
	FAN_SPD_CTRL_OUT	:out std_logic;
	
--	CTRL
	LTC_WRITE_EN	:	out	std_logic;
	EN_1V_MAC_N		:	out std_logic;

	--	LED interface
	FAN_LED		:out std_logic_vector( 9 downto 0);
	SYS_LED		:out std_logic_vector( 7 downto 0);
	FP_LED		:out std_logic_vector( 3 downto 0);

-- DC-DC Control
	ROV				:in std_logic_vector( 2 downto 0);

-- reset
	DEV_RESET_N	:out std_logic_vector( 7 downto 0);

 --Interrupt
	DEV_INT_N	:in std_logic_vector( 7 downto 0);
	FP_INT_N	:in std_logic_vector( 6 downto 0)

 ); 
       
 end SCX6K1; 
 
 
 
 
 architecture behv of SCX6K1 is
	constant	CPLD_REV	:std_logic_vector(7 downto 0) := "00000101";
	constant	CPLD_ADDR	:std_logic_vector(7 downto 0) := "10001110";
	signal RST_T		:std_logic;
	signal START		:std_logic;--IIC START Command
	signal START_COUNT	:std_logic;		
	signal COUNT_IIC	:integer range 0 to 36 ;    
	signal REG		    :std_logic_vector(7 downto 0);
	signal LAT_LED		:std_logic;            		    

	signal REG0_REG		:std_logic_vector(7 downto 0);
	signal R_CPLD_REG		:std_logic_vector(7 downto 0);
	signal REG1_REG		:std_logic_vector(7 downto 0);
	signal R_HWREV_REG	:std_logic_vector(7 downto 0);
	signal REG2_REG		:std_logic_vector(7 downto 0);
	signal W_FANLED_REG		:std_logic_vector(7 downto 0);
	signal REG3_REG		:std_logic_vector(7 downto 0);
	signal W_SYSLED_REG		:std_logic_vector(7 downto 0);
	signal REG4_REG		:std_logic_vector(7 downto 0);
	signal R_RPS_STUS_REG		:std_logic_vector(7 downto 0);
	signal REG5_REG		:std_logic_vector(7 downto 0);
	signal W_PB_EVENT_REG		:std_logic_vector(7 downto 0);
	signal REG6_REG		:std_logic_vector(7 downto 0);
	signal R_INT_EVENT_REG		:std_logic_vector(7 downto 0);
	signal REG7_REG		:std_logic_vector(7 downto 0);
	signal W_INT_Mask_REG		:std_logic_vector(7 downto 0);
	signal REG8_REG		:std_logic_vector(7 downto 0);
	signal R_SFP_INT_EVENT_REG		:std_logic_vector(7 downto 0);
	signal REG9_REG		:std_logic_vector(7 downto 0);
	signal W_SFP_INT_MASK_REG		:std_logic_vector(7 downto 0);
	signal REG10_REG		:std_logic_vector(7 downto 0);
	signal W_RST_REG		:std_logic_vector(7 downto 0);
	signal REG11_REG		:std_logic_vector(7 downto 0);
	signal W_CTRL_REG		:std_logic_vector(7 downto 0);
	signal REG12_REG		:std_logic_vector(7 downto 0);
	signal R_ROV_REG		:std_logic_vector(7 downto 0);
	signal REG13_REG		:std_logic_vector(7 downto 0);
	signal W_RPSLED_REG		:std_logic_vector(7 downto 0);

	signal REG0_EN	:std_logic;
	signal REG1_EN	:std_logic;
	signal REG2_EN	:std_logic;
	signal REG3_EN	:std_logic;
	signal REG4_EN	:std_logic;
	signal REG5_EN	:std_logic;
	signal REG6_EN	:std_logic;
	signal REG7_EN	:std_logic;
	signal REG8_EN	:std_logic;
	signal REG9_EN	:std_logic;
	signal REG10_EN	:std_logic;
	signal REG11_EN	:std_logic;
	signal REG12_EN	:std_logic;
	signal REG13_EN	:std_logic;
	
	signal SFP_INT_N	:std_logic;
	signal CPLD_INT_N	:std_logic;
	signal RPS_INT_N	:std_logic;
	signal RPS1_INT_N	:std_logic;
	signal RPS2_INT_N	:std_logic;
	signal RPS_PG_N		:std_logic;
	signal RPS1_PG_N	:std_logic;
	signal RPS2_PG_N	:std_logic;
	
	signal FAN1_LED_Y	:std_logic;
	signal FAN1_LED_G	:std_logic;
	signal FAN2_LED_Y	:std_logic;
	signal FAN2_LED_G	:std_logic;
	signal FAN3_LED_Y	:std_logic;
	signal FAN3_LED_G	:std_logic;
	signal FAN4_LED_Y	:std_logic;
	signal FAN4_LED_G	:std_logic;
	signal FAN5_LED_Y	:std_logic;
	signal FAN5_LED_G	:std_logic;

	signal FAN_LED_Y	:std_logic;
	signal FAN_LED_G	:std_logic;

	signal MGMT_LED_Y	:std_logic;
	signal MGMT_LED_G	:std_logic;
	signal CONSOLE_LED_Y	:std_logic;
	signal CONSOLE_LED_G	:std_logic;
	signal RPS1_LED_Y	:std_logic;
	signal RPS1_LED_G	:std_logic;
	signal RPS2_LED_Y	:std_logic;
	signal RPS2_LED_G	:std_logic;
	signal RPS_LED_Y	:std_logic;
	signal RPS_LED_G	:std_logic;
	signal RPS_LED_CTRL	:std_logic;
	
    signal COUNT_18		:std_logic;
	signal SDA_BRD_OUT	:std_logic;  
	signal SDA_BRD_OUT_EN	:std_logic;
	signal ACK_OUT_EN	:std_logic; 
	
	signal LED_CLK	:std_logic;

	signal	PB_CLK : std_logic;
	signal	keyin : std_logic_vector(5 downto 0);
	signal CLEAR_PB_EVENT_LATCH_r	:std_logic;
	signal CLEAR_PB_EVENT_LATCH_w	:std_logic;
	signal INT_PB_PUL_EVT_N	:std_logic;
	signal PB_COUNT	: std_logic_vector(1 downto 0);
	signal CPU_THERMTRIP_3P3: std_logic;
	signal CPU_PROCHOT_3P3: std_logic;

 begin

	RST_T	<= RST_ALL_N and RST_CPLD_N; 
	CPU_THERMTRIP_3P3 <= R_INT_EVENT_REG(7) or W_INT_Mask_REG(7);
	CPU_PROCHOT_3P3 <= RIO(2);

	
SDA_OUT:process(ACK_OUT_EN,SDA_BRD_OUT_EN,SDA_BRD_OUT) --Control the output as ACK or data out or hi-impedance
begin
	if (ACK_OUT_EN='1') then 
		SDA_BRD	<='0'; 
	elsif (SDA_BRD_OUT_EN='1')then
		SDA_BRD	<= SDA_BRD_OUT; 
	else
		SDA_BRD	<='Z';
	end if;
  end process;

ACK_EN:process(RST_T,SCLK_BRD,COUNT_IIC,REG,COUNT_18) --Control the ACK response time
begin
	if ( RST_T = '0' ) then
		ACK_OUT_EN<='0';
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=7 and  REG(7 downto 0)=CPLD_ADDR ) or COUNT_IIC=16 or (COUNT_IIC=25 and COUNT_18 ='0' ) or (COUNT_IIC=26 and COUNT_18 ='1' ) then
				ACK_OUT_EN	<='1';
		else ACK_OUT_EN	<='0';
		end if;
	end if;
end process;

COUNT_18_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,START)
begin
	if ( RST_T ='0' ) then
		COUNT_18	<='0';
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC =19 and START ='1')then 
			COUNT_18  <='1';                  --read operation
		elsif((COUNT_IIC =19 and START ='0')or COUNT_IIC = 0 )then
			COUNT_18  <='0';                  --write operation 
		end if;                               
	end if;
end process;

LAT_LED_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,REG) --access address latch(I2C pick this CPLD.)
begin
	if ( RST_T ='0' ) then
		LAT_LED	<='0';
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if ((COUNT_IIC=7 and REG(7 downto 0)=CPLD_ADDR))then 
			LAT_LED	<='1';
		elsif(COUNT_IIC=0)then
			LAT_LED	<='0'; 
		end if;
	end if;
end process;

START_BLK:process(RST_T,SDA_BRD,SCLK_BRD,COUNT_IIC)
begin
	if  ( RST_T ='0' ) then
		START	<='0';
	elsif ( SDA_BRD'event and SDA_BRD= '0') then
		if ( SCLK_BRD='1' ) then
			START	<='1';
		elsif((COUNT_IIC >1 and COUNT_IIC <17) or COUNT_IIC>21)then
			START	<='0';
		end if;
	end if;
end process;

START_COUNT_BLK:process(RST_T,SCLK_BRD,START,COUNT_IIC,REG,COUNT_18)
begin
	if ( RST_T ='0') then
		START_COUNT	<='0';
	elsif ( SCLK_BRD'event and SCLK_BRD= '0') then
		if ( START ='1' ) then
			START_COUNT  <='1';
		elsif ((COUNT_IIC=7 and REG(7 downto 0) /= CPLD_ADDR) or (COUNT_IIC=36 and COUNT_18='1') or (COUNT_IIC=26 and COUNT_18='0')) then
			START_COUNT	<='0';
		end if;
	end if;
end process;

COUNT_IIC_BLK:process(RST_T,SCLK_BRD,START_COUNT,COUNT_IIC)
begin
	if ( RST_T='0' ) then
		COUNT_IIC	<=0;
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if ( START_COUNT='1' ) then
			COUNT_IIC <=COUNT_IIC + 1;
		else COUNT_IIC<= 0; 
		end if;
	end if;
end process;

INPUT_BLK:process(RST_T,SCLK_BRD)
begin
	if ( RST_T='0' ) then
		REG <=(OTHERS=>'0');
	elsif ( SCLK_BRD'event and SCLK_BRD='1' ) then
		REG(0)	<=SDA_BRD;
		for i in 0 to 6 loop         --reg 7     6    5     4     3     2      1     0
			REG(i+1)	<=REG(i);--bit                       A2    A1     A0     R/W
		end loop;
	end if;
end process;


	R_CPLD_REG(7 downto 0) <= CPLD_REV; 
	REG0_REG <= R_CPLD_REG;

	R_HWREV_REG(7 downto 0) <= "0000" & HW_REV;
	REG1_REG <= R_HWREV_REG;
	REG4_REG <= R_RPS_STUS_REG;
	REG6_REG <= R_INT_EVENT_REG;
	REG8_REG <= R_SFP_INT_EVENT_REG;

	REG12_REG <= R_ROV_REG;
	R_ROV_REG(7 downto 0) <= RIO & "0" &ROV( 2 downto 0);


		R_RPS_STUS_REG(7 downto 0) <= RPS2_PRSNT_N & "1" & RPS2_FAIL_N & RPS2_DCOK_N & RPS1_PRSNT_N & "1" & RPS1_FAIL_N & RPS1_DCOK_N;
		R_INT_EVENT_REG(7 downto 0) <= DEV_INT_N(7 downto 0);
		R_SFP_INT_EVENT_REG(7 downto 0) <= "1" & FP_INT_N;

	RPS1_INT_N <= RPS1_FAIL_N;
	RPS2_INT_N <= RPS2_FAIL_N;
	RPS_INT_N <= RPS2_INT_N and RPS1_INT_N;
	RPS_INT_ON <= RPS_INT_N;
	RPS1_PG_N <= RPS1_DCOK_N;
	RPS2_PG_N <= RPS2_DCOK_N;
	RPS_PG_N <= RPS1_PG_N and RPS2_PG_N;
	
	SFP_INT_ON <= SFP_INT_N;
	SFP_INT_N  <=   (R_SFP_INT_EVENT_REG(6) or W_SFP_INT_MASK_REG(6)) and 
                       (R_SFP_INT_EVENT_REG(5) or W_SFP_INT_MASK_REG(5)) and (R_SFP_INT_EVENT_REG(4) or W_SFP_INT_MASK_REG(4)) and
                       (R_SFP_INT_EVENT_REG(3) or W_SFP_INT_MASK_REG(3)) and (R_SFP_INT_EVENT_REG(2) or W_SFP_INT_MASK_REG(2)) and
                       (R_SFP_INT_EVENT_REG(1) or W_SFP_INT_MASK_REG(1)) and (R_SFP_INT_EVENT_REG(0) or W_SFP_INT_MASK_REG(0));

	CPLD_INT_ON <= CPLD_INT_N;
	CPLD_INT_N <=   (R_INT_EVENT_REG(7) or W_INT_Mask_REG(7)) and (R_INT_EVENT_REG(6) or W_INT_Mask_REG(6)) and 
                       (R_INT_EVENT_REG(5) or W_INT_Mask_REG(5)) and (R_INT_EVENT_REG(4) or W_INT_Mask_REG(4)) and
                       (R_INT_EVENT_REG(3) or W_INT_Mask_REG(3)) and (R_INT_EVENT_REG(2) or W_INT_Mask_REG(2)) and
                       (R_INT_EVENT_REG(1) or W_INT_Mask_REG(1)) and (R_INT_EVENT_REG(0) or W_INT_Mask_REG(0)) and INT_PB_PUL_EVT_N;

	TS_INT_ON <= '1';	





RW_EN_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,REG(3 downto 0))
begin
	if ( RST_T= '0' ) then
		REG0_EN	<='0';
		REG1_EN <='0';
		REG2_EN	<='0';
		REG3_EN	<='0';
		REG4_EN	<='0';
		REG5_EN	<='0';
		REG6_EN <='0';
		REG7_EN <='0';
		REG8_EN	<='0';
		REG9_EN	<='0';
		REG10_EN <='0';
		REG11_EN <= '0';
		REG12_EN <= '0';
		REG13_EN <= '0';

	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=16 ) then
			if ( REG(3 downto 0)="0000" )then		--offset	0x0		CPLD revision register              Read Only
				REG0_EN    <='1';
			end if;
			if ( REG(3 downto 0)="0001" )then		--offset	0x1		HW_REV register              Read Only
				REG1_EN    <='1';
			end if;
			if ( REG(3 downto 0)="0010" )then		--offset	0x2		FAN LED indication register         Write Only
				REG2_EN   <='1';
			end if; 
			if ( REG(3 downto 0)="0011" )then		--offset	0x3		SYSTEM_LED indication register      Write Only
				REG3_EN <='1';
			end if; 
			if ( REG(3 downto 0)="0100" )then		--offset	0x4		PSU status register                 Read Only		
				REG4_EN <='1'; 
			end if;
			if ( REG(3 downto 0)="0101" )then		--offset	0x5		Push Button Event register                Read/Write Only
				REG5_EN <='1';  
			end if;          
			if  (  REG(3 downto 0)="0110" )then		--offset	0x6		INT event register                  Read Only
				REG6_EN <='1';  
			end if;
			if  (  REG(3 downto 0)="0111" )then		--offset	0x7		INT event mask register             Write Only
				REG7_EN <='1';  
			end if;
			if  (  REG(3 downto 0)="1000" )then		--offset	0x8		SFP/QSFP INT event register         Read Only
				REG8_EN <='1';  
			end if;
			if  (  REG(3 downto 0)="1001" )then		--offset	0x9		SFP/QSFP INT event mask register    Write Only
				REG9_EN <='1';  
			end if;
			if  (  REG(3 downto 0)="1010" )then		--offset	0xA		Device reset register               Write Only 
				REG10_EN <='1';  
			end if;
			if  (  REG(3 downto 0)="1011" )then		--offset	0xB		Control register                Write Only
				REG11_EN <='1';  
			end if;          
			if  (  REG(3 downto 0)="1100" )then 		--offset 	0xC		ROV status register                 Read Only
				REG12_EN <='1';
			end if;
			if  (  REG(3 downto 0)="1101" )then 		--offset 	0xD		PSU LED register                 Write Only
				REG13_EN <='1';
			end if;

		elsif (COUNT_IIC= 0 )then
			REG0_EN		<='0';
			REG1_EN <='0';
			REG2_EN	<='0';
			REG3_EN	<='0';
			REG4_EN	<='0';
			REG5_EN	<='0';
			REG6_EN <='0';
			REG7_EN <='0';
			REG8_EN	<='0';
			REG9_EN	<='0';
			REG10_EN <='0';
			REG11_EN <= '0';
			REG12_EN <= '0';
			REG13_EN <= '0';
		end if;
	end if;
end process;

    

R_CPLD_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,COUNT_18,REG0_EN,REG1_EN,REG2_EN,REG3_EN,REG4_EN,REG5_EN,REG6_EN,REG7_EN,REG8_EN,
REG9_EN,REG10_EN,REG11_EN,REG12_EN,REG13_EN)
begin
	if ( RST_T='0' ) then
		SDA_BRD_OUT_EN	<='0';
		elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
			if ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG0_EN ='1' and COUNT_18 ='1') then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG0_REG(34-COUNT_IIC) ;           
                  --Bit        28     29      30      31      32      33      34      35
                  --read_Reg    7      6       5       4       3       2       1       0
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG1_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG1_REG(34-COUNT_IIC) ;         
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG2_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG2_REG(34-COUNT_IIC) ;         
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG3_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG3_REG(34-COUNT_IIC) ;
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG4_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG4_REG(34-COUNT_IIC) ;
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG5_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG5_REG(34-COUNT_IIC) ;
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG6_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG6_REG(34-COUNT_IIC) ;               
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG7_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG7_REG(34-COUNT_IIC) ;              
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG8_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG8_REG(34-COUNT_IIC) ;              
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG9_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG9_REG(34-COUNT_IIC) ;              
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG10_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG10_REG(34-COUNT_IIC) ;              
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG11_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG11_REG(34-COUNT_IIC) ;              
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG12_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG12_REG(34-COUNT_IIC) ;              
			elsif ((COUNT_IIC >= 27 and COUNT_IIC <= 34) and LAT_LED='1'and REG13_EN ='1'and COUNT_18 ='1')then
				SDA_BRD_OUT_EN	<='1';		
				SDA_BRD_OUT	<= REG13_REG(34-COUNT_IIC) ;              
			else  SDA_BRD_OUT_EN <= '0';		                 	 
		end if;  
	end if;    
end process; 

---------------------- Write block  
W_SYSLED_REG <= REG3_REG;
W_SYSLED_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG3_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		REG3_REG <= "00000011";
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG3_EN ='1'and COUNT_18 ='0') then 
			REG3_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Lacth the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_PB_EVENT_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG5_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		W_PB_EVENT_REG(7) <= '0';
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG5_EN ='1'and COUNT_18 ='0') then 
			W_PB_EVENT_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Latch the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_INT_Mask_REG <= REG7_REG;
W_INT_Mask_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG7_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		REG7_REG <= "11111111";
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG7_EN ='1'and COUNT_18 ='0') then 
			REG7_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Latch the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_SFP_INT_MASK_REG <= REG9_REG;
W_SFP_INT_MASK_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG9_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		REG9_REG <= "11111111";
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG9_EN ='1'and COUNT_18 ='0') then 
			REG9_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Latch the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_RST_BLK:process(RST_T,W_RST_REG)
begin
	if ( RST_T='0' ) then
		DEV_RESET_N <= "00000000";
	else
		DEV_RESET_N(7) <= not W_RST_REG(7);
		DEV_RESET_N(6) <= not W_RST_REG(6);
		DEV_RESET_N(5 downto 0) <= W_RST_REG(5 downto 0);
	end if;
end process;

W_RST_REG <= REG10_REG;

W_RST_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG10_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		REG10_REG <= "11111111";
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG10_EN ='1'and COUNT_18 ='0') then 
			REG10_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Latch the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_CTRL_REG <= REG11_REG;
LTC_WRITE_EN <= W_CTRL_REG(2);
EN_1V_MAC_N <= W_CTRL_REG(3);
W_CTRL_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG11_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		REG11_REG <= "00000000";
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG11_EN ='1'and COUNT_18 ='0') then 
			REG11_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Latch the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_RPSLED_REG <= REG13_REG;
RPS_LED_CTRL <= W_RPSLED_REG(6);
W_RPSLED_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG13_EN,COUNT_18)
  begin
	if ( RST_T='0' ) then
		REG13_REG <= "00000000";
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if (COUNT_IIC=25 and  LAT_LED ='1' and REG13_EN ='1'and COUNT_18 ='0') then 
			REG13_REG(7 downto 0)  <= REG(7 downto 0) ; -- REG(7:0) Latch the last 6 bits at 25th CLK
		end if;
	end if;
end process;

W_FANLED_REG <= REG2_REG;
W_FAN_LED_BLK:process(RST_T,SCLK_BRD,COUNT_IIC,LAT_LED,REG2_EN,COUNT_18)
begin
	if ( RST_T='0' ) then
		REG2_REG <= "00000000"; --dark
	elsif ( SCLK_BRD'event and SCLK_BRD='0' ) then
		if ( COUNT_IIC=25 and LAT_LED='1'and REG2_EN ='1'and COUNT_18 ='0')then 
			REG2_REG <=REG(7 downto 0) ; --REG(3:0) Latch the last 2 bits at 25th CLK
		end if;         
	end if;     
end process;


----------------------FAN CTRL
FAN_CTRL_BLK:process( RST_T, CPU_THERMTRIP_3P3, CPU_PROCHOT_3P3, FAN_SPD_CTRL_IN)
begin
	if ( (RST_T='0') or (CPU_THERMTRIP_3P3='0') or (CPU_PROCHOT_3P3='0')) then
		FAN_SPD_CTRL_OUT <= '0';
	else
		FAN_SPD_CTRL_OUT <= (not FAN_SPD_CTRL_IN);
	end if;     
end process;
----------------------------------------------- LED
FAN_LED <= FAN5_LED_Y & FAN5_LED_G & FAN4_LED_Y & FAN4_LED_G & FAN3_LED_Y & FAN3_LED_G & FAN2_LED_Y & FAN2_LED_G & FAN1_LED_Y & FAN1_LED_G;
SYS_LED <= RPS2_LED_Y & RPS2_LED_G & RPS1_LED_Y & RPS1_LED_G & CONSOLE_LED_Y & CONSOLE_LED_G & MGMT_LED_Y & MGMT_LED_G;
FP_LED(1 downto 0) <= FAN_LED_Y & FAN_LED_G;
FP_LED(3 downto 2) <= RPS_LED_Y & RPS_LED_G;


LED_CLK <= SLOW_CLK2;

Count_PB_CLK:process(LED_CLK)
begin
	if ( LED_CLK'event and LED_CLK='1' ) then
		PB_COUNT <= PB_COUNT +1;
	end if;
end process;

	PB_CLK <= PB_COUNT(1);


FAN_LED_BLK:process(W_FANLED_REG(7 downto 0), W_SYSLED_REG(7 downto 4), LED_CLK)
begin
	case W_FANLED_REG(1 downto 0) is
		when "00" =>
			FAN1_LED_Y	<= W_FANLED_REG(1); 
			FAN1_LED_G	<= W_FANLED_REG(0);
		when "01" => 
			FAN1_LED_Y	<= W_FANLED_REG(1); 
			FAN1_LED_G	<= W_FANLED_REG(0);
		when "10" => --amber blinking
			FAN1_LED_Y	<=  LED_CLK;
			FAN1_LED_G	<=  '0'; 
		when "11" => --green blinking
			FAN1_LED_Y	<= '0'; 
			FAN1_LED_G	<= LED_CLK;  
		when others =>
			FAN1_LED_Y	<= '0'; 
			FAN1_LED_G	<= '0';
	end case;
	case W_FANLED_REG(3 downto 2) is
		when "00" =>
			FAN2_LED_Y	<= W_FANLED_REG(3);
			FAN2_LED_G	<= W_FANLED_REG(2);
		when "01" =>
			FAN2_LED_Y	<= W_FANLED_REG(3);
			FAN2_LED_G	<= W_FANLED_REG(2);
		when "10" =>
			FAN2_LED_Y	<=  LED_CLK;       
			FAN2_LED_G	<=  '0';  
		when "11" =>
			FAN2_LED_Y	<= '0'; 
			FAN2_LED_G	<= LED_CLK;  
		when others =>
			FAN2_LED_Y	<= '0'; 
			FAN2_LED_G	<= '0';
	end case;
	case W_FANLED_REG(5 downto 4) is
		when "00" =>
			FAN3_LED_Y	<= W_FANLED_REG(5);
			FAN3_LED_G	<= W_FANLED_REG(4);
		when "01" =>
			FAN3_LED_Y	<= W_FANLED_REG(5);
			FAN3_LED_G	<= W_FANLED_REG(4);
		when "10" =>
			FAN3_LED_Y	<=  LED_CLK;       
			FAN3_LED_G	<=  '0';  
		when "11" =>
			FAN3_LED_Y	<= '0'; 
			FAN3_LED_G	<= LED_CLK;  
		when others =>
			FAN3_LED_Y	<= '0'; 
			FAN3_LED_G	<= '0';
	end case;
	case W_FANLED_REG(7 downto 6) is
		when "00" =>
			FAN4_LED_Y	<= W_FANLED_REG(7);
			FAN4_LED_G	<= W_FANLED_REG(6);
		when "01" =>
			FAN4_LED_Y	<= W_FANLED_REG(7);
			FAN4_LED_G	<= W_FANLED_REG(6);
		when "10" =>
			FAN4_LED_Y	<=  LED_CLK;      
			FAN4_LED_G	<=  '0';  
		when "11" =>
			FAN4_LED_Y	<= '0'; 
			FAN4_LED_G	<= LED_CLK;  
		when others =>
			FAN4_LED_Y	<= '0'; 
			FAN4_LED_G	<= '0';
	end case;
	case W_SYSLED_REG(7 downto 6) is
		when "00" =>
			FAN5_LED_Y	<= W_SYSLED_REG(7);
			FAN5_LED_G	<= W_SYSLED_REG(6);
		when "01" =>
			FAN5_LED_Y	<= W_SYSLED_REG(7);
			FAN5_LED_G	<= W_SYSLED_REG(6);
		when "10" =>
			FAN5_LED_Y	<=  LED_CLK;
			FAN5_LED_G	<=  '0';
		when "11" =>
			FAN5_LED_Y	<= '0';
			FAN5_LED_G	<= LED_CLK;
		when others =>
			FAN5_LED_Y	<= '0';
			FAN5_LED_G	<= '0';
	end case;
	case W_SYSLED_REG(5 downto 4) is
		when "00" =>
			FAN_LED_Y	<= W_SYSLED_REG(5);
			FAN_LED_G	<= W_SYSLED_REG(4);
		when "01" =>
			FAN_LED_Y	<= W_SYSLED_REG(5);
			FAN_LED_G	<= W_SYSLED_REG(4);
		when "10" =>
			FAN_LED_Y	<=  LED_CLK;
			FAN_LED_G	<=  '0';  
		when "11" =>
			FAN_LED_Y	<= '0';
			FAN_LED_G	<= LED_CLK;
		when others =>
			FAN_LED_Y	<= '0';
			FAN_LED_G	<= '0';
		end case;
end process;

SYS_LED_BLK:process(W_SYSLED_REG(3 downto 0), LED_CLK)
begin
	case W_SYSLED_REG(3 downto 2) is
		when "00" => 
			CONSOLE_LED_Y	<= W_SYSLED_REG(3);
			CONSOLE_LED_G	<= W_SYSLED_REG(2);
		when "01" =>
			CONSOLE_LED_Y	<= W_SYSLED_REG(3);
			CONSOLE_LED_G	<= W_SYSLED_REG(2);
		when "10" => --amber blinking
			CONSOLE_LED_Y	<=  LED_CLK;
			CONSOLE_LED_G	<=  '0';
		when "11" => --green blinking
			CONSOLE_LED_Y	<= '0'; 
			CONSOLE_LED_G	<= LED_CLK;  
		when others =>
			CONSOLE_LED_Y	<= '0'; 
			CONSOLE_LED_G	<= '0';
	end case;
	case W_SYSLED_REG(1 downto 0) is
		when "00" =>
			MGMT_LED_Y	<= W_SYSLED_REG(1);
			MGMT_LED_G	<= W_SYSLED_REG(0);
		when "01" =>
			MGMT_LED_Y	<= W_SYSLED_REG(1);
			MGMT_LED_G	<= W_SYSLED_REG(0);
		when "10" => --amber blinking
			MGMT_LED_Y	<=  LED_CLK;
			MGMT_LED_G	<=  '0';
		when "11" => --green blinking
			MGMT_LED_Y	<= '0';
			MGMT_LED_G	<= LED_CLK;
		when others =>
			MGMT_LED_Y	<= '0';
			MGMT_LED_G	<= '0';
	end case;
end process;


RPS_LED_BLK:process(W_RPSLED_REG(5 downto 0), LED_CLK)
begin
	case W_RPSLED_REG(3 downto 2) is
		when "00" =>
			RPS2_LED_Y	<= W_RPSLED_REG(3); 
			RPS2_LED_G	<= W_RPSLED_REG(2);
		when "01" =>
			RPS2_LED_Y	<= W_RPSLED_REG(3); 
			RPS2_LED_G	<= W_RPSLED_REG(2);
		when "10" => --amber blinking
			RPS2_LED_Y	<=  LED_CLK;
			RPS2_LED_G	<=  '0'; 
		when "11" => --amber
			RPS2_LED_Y	<= '1'; 
			RPS2_LED_G	<= '0';  
		when others =>
			RPS2_LED_Y	<= '0'; 
			RPS2_LED_G	<= '0';
	end case;
	case W_RPSLED_REG(1 downto 0) is
		when "00" =>
			RPS1_LED_Y	<= W_RPSLED_REG(1); 
			RPS1_LED_G	<= W_RPSLED_REG(0);
		when "01" =>
			RPS1_LED_Y	<= W_RPSLED_REG(1); 
			RPS1_LED_G	<= W_RPSLED_REG(0);
		when "10" => --amber blinking
			RPS1_LED_Y	<=  LED_CLK;
			RPS1_LED_G	<=  '0'; 
		when "11" => --amber
			RPS1_LED_Y	<= '1'; 
			RPS1_LED_G	<= '0';  
		when others =>
			RPS1_LED_Y	<= '0'; 
			RPS1_LED_G	<= '0';
	end case;
end process;



PHJ_LED_BLK:process(W_RPSLED_REG(5 downto 4), LED_CLK, RPS_INT_N, RPS_LED_CTRL )
begin
	if ( RPS_LED_CTRL = '0') then
		RPS_LED_Y	<= ( not RPS_INT_N ) and LED_CLK;
		RPS_LED_G	<= RPS_INT_N;
	elsif ( RPS_LED_CTRL = '1') then
		case W_RPSLED_REG(5 downto 4) is
			when "00" => 
				RPS_LED_Y	<= W_RPSLED_REG(5); 
				RPS_LED_G	<= W_RPSLED_REG(4);
			when "01" =>
				RPS_LED_Y	<= W_RPSLED_REG(5); 
				RPS_LED_G	<= W_RPSLED_REG(4);
			when "10" => --amber blinking
				RPS_LED_Y	<=  LED_CLK;
				RPS_LED_G	<=  '0'; 
			when "11" => --amber
				RPS_LED_Y	<= '1'; 
				RPS_LED_G	<= '0';  
			when others =>
				RPS_LED_Y	<= '0'; 
				RPS_LED_G	<= '0';
		end case;
	
	end if;
end process;


-- Push Button Event

CLEAR_PB_EVENT_LATCH_w <= W_PB_EVENT_REG(7);
REG5_REG <= CLEAR_PB_EVENT_LATCH_r & "111111" & INT_PB_PUL_EVT_N;
CLEAR_PB_EVENT_LATCH_r <= CLEAR_PB_EVENT_LATCH_w;


process(PB_CLK,RST_T,CLEAR_PB_EVENT_LATCH_r)
begin
	if( CLEAR_PB_EVENT_LATCH_r = '1' or RST_T='0' )then    --RST_T='0'1=clear,0=unclear
		INT_PB_PUL_EVT_N  <= '1';      --0=exist event ,1= not exist event
	elsif (PB_CLK='0' and PB_CLK'event )then
		keyin(5 downto 0) <= keyin(4 downto 0) & (not PB_PULL_N);
		if (keyin(5 downto 0) = "111111") then
			INT_PB_PUL_EVT_N <='0';
		end if;
	end if;

end process;	

end behv;
